==> rameez_animated_login_screen-0.0.1.tar.gz: README.md <==
<!-- 
This README describes the package. If you publish this package to pub.dev,
this README's contents appear on the landing page for your package.

For information about how to write a good package README, see the guide for
[writing package pages](https://dart.dev/guides/libraries/writing-package-pages). 

For general information about developing packages, see the Dart guide for
[creating packages](https://dart.dev/guides/libraries/create-library-packages)
and the Flutter guide for
[developing packages and plugins](https://flutter.dev/developing-packages). 
-->

TODO: Its the First version need improvements.

## Features

TODO: This is a ready made login screen with some annimation if you pass the flare image Test.flr which is availabe in example it will auto handle the animations

## Getting started

TODO: flutter pub add rameez_animated_login_screen 

## Usage

TODO: Example availabe in 
 `/example` folder. 

```dart
RameezAnimatedLoginScreen(
                //flareController: flareController,
                passwordFieldCaretMovement: (Offset globalCaretPosition) {},
                userFieldCaretMovement: (Offset globalCaretPosition) {},
                //flareImage: 'assets/Test.flr',
                routeAfterSuccessFulSignIn: () {
                  Navigator.of(context).push(
                    MaterialPageRoute<void>(
                      builder: (BuildContext context) => const Page1(),
                    ),
                  );
                },
                validateUserNameAndPassword: validate,
                defaultAnimation: true, passwordLabel: 'Enter Password',
                usernameLabel: 'Enter User Name',
              )

              bool validate(LoginData loginData) {
    print(loginData.password);
    print(loginData.name);
    if (loginData.name == "ram" && loginData.password == "rame") {
      return true;
    }
    return false;
  }
```

## Additional information

TODO: Please suggest improvements as its my first package and is learning more.

==> rameez_animated_login_screen-0.0.2.tar.gz: README.md <==
<!-- 
This README describes the package. If you publish this package to pub.dev,
this README's contents appear on the landing page for your package.

For information about how to write a good package README, see the guide for
[writing package pages](https://dart.dev/guides/libraries/writing-package-pages). 

For general information about developing packages, see the Dart guide for
[creating packages](https://dart.dev/guides/libraries/create-library-packages)
and the Flutter guide for
[developing packages and plugins](https://flutter.dev/developing-packages). 
-->

TODO: Its the First version need improvements.

## Features

 This is a ready made login screen with some annimation if you pass the flare image Test.flr which is availabe in example it will auto handle the animations

## Getting started

flutter pub add rameez_animated_login_screen 

## Usage

TODO: Example availabe in 
 `/example` folder. 

```dart
RameezAnimatedLoginScreen(
                //flareController: flareController,
                passwordFieldCaretMovement: (Offset globalCaretPosition) {},
                userFieldCaretMovement: (Offset globalCaretPosition) {},
                //flareImage: 'assets/Test.flr',
                routeAfterSuccessFulSignIn: () {
                  Navigator.of(context).push(
                    MaterialPageRoute<void>(
                      builder: (BuildContext context) => const Page1(),
                    ),
                  );
                },
                validateUserNameAndPassword: validate,
                defaultAnimation: true, passwordLabel: 'Enter Password',
                usernameLabel: 'Enter User Name',
              )

              bool validate(LoginData loginData) {
    print(loginData.password);
    print(loginData.name);
    if (loginData.name == "ram" && loginData.password == "rame") {
      return true;
    }
    return false;
  }
```

## How It Works

![](Login.gif)

## Additional information

TODO: Please suggest improvements as its my first package and is learning more.
